﻿using System;
using System.Collections;
using System.Windows;

using DevExpress.Xpf.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
 
            this.gridControl.ItemsSource = new NorthwindEntities().Products;

            this.gridControl.Columns["UnitPrice"].GroupIndex = 0;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 그리드 컨트롤 커스텀 컬럼 그룹 처리하기 - gridControl_CustomColumnGroup(sender, e)

        /// <summary>
        /// 그리드 컨트롤 커스텀 컬럼 그룹 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridControl_CustomColumnGroup(object sender, CustomColumnSortEventArgs e)
        {
            if(e.Column.FieldName == "UnitPrice")
            {
                double value1        = Math.Floor(Convert.ToDouble(e.Value1) / 10);
                double value2        = Math.Floor(Convert.ToDouble(e.Value2) / 10);
                int    compareResult = Comparer.Default.Compare(value1, value2);

                if(value1 > 9 && value2 > 9)
                {
                    compareResult = 0;
                }

                e.Result  = compareResult;
                e.Handled = true;
            }
        }

        #endregion
        #region 그리드 컨트롤 커스텀 그룹 표시 텍스트 처리하기 - gridControl_CustomGroupDisplayText(sender, e)

        /// <summary>
        /// 그리드 컨트롤 커스텀 그룹 표시 텍스트 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridControl_CustomGroupDisplayText(object sender, CustomGroupDisplayTextEventArgs e)
        {
            if(e.Column.FieldName != "UnitPrice")
            {
                return;
            }

            int groupLevel = this.gridControl.GetRowLevelByRowHandle(e.RowHandle);

            if(groupLevel != e.Column.GroupIndex)
            {
                return;
            }

            string interval = GetIntervalString(e.Value);

            e.DisplayText = interval;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 간격 문자열 구하기 - GetIntervalString(value) 

        /// <summary>
        /// 간격 문자열 구하기
        /// </summary>
        /// <param name="value">값</param>
        /// <returns>간격 문자열</returns>
        private string GetIntervalString(object value)
        {
            double valueDouble = Math.Floor(Convert.ToDouble(value) / 10);

            string interval = string.Format("{0:c} - {1:c} ", valueDouble * 10, (valueDouble + 1) * 10);

            if(valueDouble > 9)
            {
                interval = string.Format(">= {0:c} ", 100);
            }

            return interval;
        }

        #endregion
    }
}